from dataclasses import dataclass

@dataclass
class getMeetingInfogResponse:
    returncode: str
    meetingName: str
    meetingID: str
    internalMeetingID: str
    createTime: int
    createDate: str
    voiceBridge: int
    dialNumber: str
    attendeePW: str
    moderatorPW: str
    running: bool
    duration: int
    hasUserJoined: bool
    recording: bool
    hasBeenForciblyEnded: bool
    startTime: int
    endTime: int
    participantCount: int
    listenerCount: int
    voiceParticipantCount: int
    videoCount: int
    maxUsers: int
    moderatorCount: int
    attendees: dict
    isBreakout: bool
    metadata: str
    breakoutRooms: dict = None


import setuptools

setuptools.setup(
    name="bigbluepy",
    version="0.1.8",
    author="UWSGI",
    url="https://github.com/its0x4d/bigbluepython-python",
    author_email="mosydev2016@gmail.com",
    description="An unofficial Bigbluebutton api.",
    packages=setuptools.find_packages(),
    platforms=['any'],
    license="MIT",
    install_requires=['packaging', 'xmltodict', 'requests'],
    long_description="An unofficial bigbluebutton api written in python",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
